## Version 0.0.61

This new version introduces caching to improve performance and enhances the paper selection process for a more interactive experience.

### New Features

- Enabled use of cache in the chat function to improve performance (013dae) (Eric Ma)
- Enhanced the paper selection process to handle single paper scenario and provide a more interactive selection process for multiple papers (013dae) (Eric Ma)

### Bug Fixes

- None in this release

### Deprecations

- None in this release
